##  Adding a Custom Field
By adding custom fields, you can capture more specific or unique data that is not provided by predefined fields. This enables you to enrich the data set, allowing for a more comprehensive and nuanced understanding of your IT landscape.
To add a custom field, follow these steps:
  1. On the fact sheet configuration page, select a subsection where you want to place the field, then click Add field.
  2. On the right-side panel, configure field parameters.
![Adding a Custom Field](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2756287d7a4410149644ed11ae5efeaf_LowRes.png)
Adding a Custom Field
  3. Review and save the changes.
